aboutsummaryrefslogtreecommitdiffstats
path: root/packages/contract-wrappers/src/types.ts
diff options
context:
space:
mode:
authorLeonid Logvinov <logvinov.leon@gmail.com>2018-06-29 16:06:34 +0800
committerLeonid Logvinov <logvinov.leon@gmail.com>2018-06-29 22:52:54 +0800
commitd84bb7ed7e25e8ed01c1228f7792f901db3d60e4 (patch)
tree69372adfc19adad821c4c7fe22fb3141fa262649 /packages/contract-wrappers/src/types.ts
parentf02ada2d11b5dec6bc4615cba43a932821501473 (diff)
downloaddexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.tar
dexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.tar.gz
dexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.tar.bz2
dexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.tar.lz
dexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.tar.xz
dexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.tar.zst
dexon-0x-contracts-d84bb7ed7e25e8ed01c1228f7792f901db3d60e4.zip
Remove tokenTransferProxyAddress from config
Diffstat (limited to 'packages/contract-wrappers/src/types.ts')
-rw-r--r--packages/contract-wrappers/src/types.ts8
1 files changed, 4 insertions, 4 deletions
diff --git a/packages/contract-wrappers/src/types.ts b/packages/contract-wrappers/src/types.ts
index 649133584..eb0b5abfe 100644
--- a/packages/contract-wrappers/src/types.ts
+++ b/packages/contract-wrappers/src/types.ts
@@ -105,8 +105,8 @@ export type SyncMethod = (...args: any[]) => any;
* gasPrice: Gas price to use with every transaction
* exchangeContractAddress: The address of an exchange contract to use
* zrxContractAddress: The address of the ZRX contract to use
* tokenRegistryContractAddress: The address of a token registry contract to use
* tokenTransferProxyContractAddress: The address of the token transfer proxy contract to use
* orderWatcherConfig: All the configs related to the orderWatcher
*/
export interface ContractWrappersConfig {
@@ -114,8 +114,8 @@ export interface ContractWrappersConfig {
gasPrice?: BigNumber;
exchangeContractAddress?: string;
zrxContractAddress?: string;
- tokenRegistryContractAddress?: string;
- tokenTransferProxyContractAddress?: string;
+ erc20ProxyContractAddress?: string;
+ erc721ProxyContractAddress?: string;
}
/**
@@ -105,8 +105,8 @@ export type SyncMethod = (...args: any[]) => any;
* exchangeContractAddress: The address of an exchange contract to use
* zrxContractAddress: The address of the ZRX contract to use
- * tokenRegistryContractAddress: The address of a token registry contract to use
- * tokenTransferProxyContractAddress: The address of the token transfer proxy contract to use
+ * erc20ProxyContractAddress: The address of the erc20 token transfer proxy contract to use
+ * erc721ProxyContractAddress: The address of the erc721 token transfer proxy contract to use
* orderWatcherConfig: All the configs related to the orderWatcher
*/